Class: GoogleVideo::PlaylistEntry

Inherits:
Record
  • Object
show all
Defined in:
lib/google-video.rb

Overview

Describes an alternate video as listed in the “Playlist” tab for a particular video’s detailed view page. Parameters are specified via a hash passed to the object on construction mapping attribute names to their respective values.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Record

#initialize

Constructor Details

This class inherits a constructor from GoogleVideo::Record

Instance Attribute Details

#durationObject (readonly)

the duration of the video in prose, e.g. “1hr 49min” or “3min”.



216
217
218
# File 'lib/google-video.rb', line 216

def duration
  @duration
end

#page_urlObject (readonly)

the full url at which the video is available for viewing.



222
223
224
# File 'lib/google-video.rb', line 222

def page_url
  @page_url
end

#thumbnail_image_urlObject (readonly)

the full url to the video thumbnail image.



213
214
215
# File 'lib/google-video.rb', line 213

def thumbnail_image_url
  @thumbnail_image_url
end

#titleObject (readonly)

the title of the video.



210
211
212
# File 'lib/google-video.rb', line 210

def title
  @title
end

#upload_userObject (readonly)

the name of the user who uploaded the video.



219
220
221
# File 'lib/google-video.rb', line 219

def upload_user
  @upload_user
end