Class: GoogleVideo::VideoFrameThumbnail

Inherits:
Object
  • Object
show all
Defined in:
lib/google-video.rb

Overview

Provides a miniature snapshot of a point in time within a full video. On the actual Google Video site these are linked to auto-pan the video to the start of the scene represented in the thumbnail, but for us there’s no direct link of meaning so we’ve only got static content which is nevertheless of potential interest and utility.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params) ⇒ VideoFrameThumbnail



186
187
188
# File 'lib/google-video.rb', line 186

def initialize (params)
  params.each { |key, value| instance_variable_set('@' + key.to_s, value) }
end

Instance Attribute Details

#thumbnail_image_urlObject (readonly)

the full url to the video frame thumbnail image.



184
185
186
# File 'lib/google-video.rb', line 184

def thumbnail_image_url
  @thumbnail_image_url
end

#titleObject (readonly)

the title of the video frame, e.g. “at 10 secs”, “at 30 secs”, etc.



181
182
183
# File 'lib/google-video.rb', line 181

def title
  @title
end