Class: GoogleVideo::VideoSearchResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/google-video.rb

Overview

Describes a response to a VideoSearchRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params) ⇒ VideoSearchResponse

Constructs a VideoSearchResponse with the supplied hash mapping attribute names to their respective values.



381
382
383
# File 'lib/google-video.rb', line 381

def initialize (params)
  params.each { |key, value| instance_variable_set('@' + key.to_s, value) }
end

Instance Attribute Details

#end_indexObject (readonly)

the 1-based ending index number of the results in this set.



368
369
370
# File 'lib/google-video.rb', line 368

def end_index
  @end_index
end

#execution_timeObject (readonly)

the time taken in seconds to execute the search query (according to Google).



374
375
376
# File 'lib/google-video.rb', line 374

def execution_time
  @execution_time
end

#request_urlObject (readonly)

the url with which the request was made of the Google Video service.



362
363
364
# File 'lib/google-video.rb', line 362

def request_url
  @request_url
end

#start_indexObject (readonly)

the 1-based starting index number of the results in this set.



365
366
367
# File 'lib/google-video.rb', line 365

def start_index
  @start_index
end

#total_result_countObject (readonly)

the total number of results in this result set.



371
372
373
# File 'lib/google-video.rb', line 371

def total_result_count
  @total_result_count
end

#videosObject (readonly)

the list of Video objects comprising the search results.



377
378
379
# File 'lib/google-video.rb', line 377

def videos
  @videos
end