Class: GoogleVideo::PlaylistEntry

Inherits:
Object
  • Object
show all
Defined in:
lib/google-video.rb

Overview

Describes an alternate video as listed in the “Playlist” tab for a particular video’s detailed view page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params) ⇒ PlaylistEntry

Returns a new instance of PlaylistEntry.



209
210
211
# File 'lib/google-video.rb', line 209

def initialize (params)
  params.each { |key, value| instance_variable_set('@' + key.to_s, value) }
end

Instance Attribute Details

#durationObject (readonly)

the duration of the video in prose, e.g. “1hr 49min” or “3min”.



201
202
203
# File 'lib/google-video.rb', line 201

def duration
  @duration
end

#page_urlObject (readonly)

the full url at which the video is available for viewing.



207
208
209
# File 'lib/google-video.rb', line 207

def page_url
  @page_url
end

#thumbnail_image_urlObject (readonly)

the full url to the video thumbnail image.



198
199
200
# File 'lib/google-video.rb', line 198

def thumbnail_image_url
  @thumbnail_image_url
end

#titleObject (readonly)

the title of the video.



195
196
197
# File 'lib/google-video.rb', line 195

def title
  @title
end

#upload_userObject (readonly)

the name of the user who uploaded the video.



204
205
206
# File 'lib/google-video.rb', line 204

def upload_user
  @upload_user
end