Class: GoogleVideo::PlaylistEntry
Overview
Describes an alternate video as listed in the “Playlist” tab for a particular video’s detailed view page. Parameters are specified via a hash passed to the object on construction mapping attribute names to their respective values.
Instance Attribute Summary collapse
-
#duration ⇒ Object
readonly
the duration of the video in prose, e.g.
-
#page_url ⇒ Object
readonly
the full url at which the video is available for viewing.
-
#thumbnail_image_url ⇒ Object
readonly
the full url to the video thumbnail image.
-
#title ⇒ Object
readonly
the title of the video.
-
#upload_user ⇒ Object
readonly
the name of the user who uploaded the video.
Method Summary
Methods inherited from Record
Constructor Details
This class inherits a constructor from GoogleVideo::Record
Instance Attribute Details
#duration ⇒ Object (readonly)
the duration of the video in prose, e.g. “1hr 49min” or “3min”.
216 217 218 |
# File 'lib/google-video.rb', line 216 def duration @duration end |
#page_url ⇒ Object (readonly)
the full url at which the video is available for viewing.
222 223 224 |
# File 'lib/google-video.rb', line 222 def page_url @page_url end |
#thumbnail_image_url ⇒ Object (readonly)
the full url to the video thumbnail image.
213 214 215 |
# File 'lib/google-video.rb', line 213 def thumbnail_image_url @thumbnail_image_url end |
#title ⇒ Object (readonly)
the title of the video.
210 211 212 |
# File 'lib/google-video.rb', line 210 def title @title end |
#upload_user ⇒ Object (readonly)
the name of the user who uploaded the video.
219 220 221 |
# File 'lib/google-video.rb', line 219 def upload_user @upload_user end |